Send patches - preferably formatted by git format-patch - to patches at archlinux32 dot org.
summaryrefslogtreecommitdiff
path: root/profiles/gnome.py
diff options
context:
space:
mode:
Diffstat (limited to 'profiles/gnome.py')
-rw-r--r--profiles/gnome.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/profiles/gnome.py b/profiles/gnome.py
index 0481eded..44fd642f 100644
--- a/profiles/gnome.py
+++ b/profiles/gnome.py
@@ -20,9 +20,9 @@ def _prep_function(*args, **kwargs):
print('Deprecated (??): xorg profile has no _prep_function() anymore')
# Ensures that this code only gets executed if executed
-# through importlib.util.spec_from_file_location("awesome", "/somewhere/awesome.py")
-# or through conventional import awesome
-if __name__ == 'awesome':
+# through importlib.util.spec_from_file_location("gnome", "/somewhere/gnome.py")
+# or through conventional import gnome
+if __name__ == 'gnome':
# Install dependency profiles
installation.install_profile('xorg')